#!/usr/bin/env python

from matplotlib import pyplot
from matplotlib import ticker

# This generates population graphs for foreign residents of Japan.
#
# https://dperkins.org/arc/2014-08-29.foreign%20resident%20population.html
# https://dperkins.org/arc/2015-03-08.foreign%20resident%20population.html
#
# SVG files are produced using matplotlib.
#
# http://matplotlib.org/users/pyplot_tutorial.html
# http://matplotlib.org/api/pyplot_api.html

population = [
(1978,	766894,	114913000),
(1979,	774505,	115890000),
(1980,	782910,	117060396),
(1981,	792946,	117661000),
(1982,	802477,	118480000),
(1983,	817129,	119307000),
(1984,	840885,	120083000),
(1985,	850612,	121048923),
(1986,	867237,	121482000),
(1987,	884025,	122069000),
(1988,	941005,	122578000),
(1989,	984455,	123069000),
(1990,	1075317,	123611167),
(1991,	1218891,	123964000),
(1992,	1281644,	124425000),
(1993,	1320748,	124829000),
(1994,	1354011,	125178000),
(1995,	1362371,	125570246),
(1996,	1415136,	125757000),
(1997,	1482707,	126057000),
(1998,	1512116,	126400000),
(1999,	1556113,	126631000),
(2000,	1686444,	126843000),
(2001,	1778462,	127149000),
(2002,	1851758,	127445000),
(2003,	1915030,	127718000),
(2004,	1973747,	126250000),
(2005,	1906689,	127767994),
(2006,	2084919,	127854000),
(2007,	2152973,	128001000),
(2008,	2217426,	128063000),
(2009,	2186121,	128047000),
(2010,	2134151,	128057352),
(2011,	2078508,	127817000),
(2012,	2033656,	127561000),
(2013,	2066445,	127350000),
(2014,	2086603,	127100000),
(2015,	2232189,	127094745),
]

years = []
foreign_residents = []
total_population = []
percent_foreign = []

for (year, foreign, total) in population:
	years.append(year)
	foreign_residents.append(foreign)
	total_population.append(total)
	percent_foreign.append(100.0 * (1.0 * foreign)/(1.0 * total))

start_year = years[0]
end_year = years[-1]
year_suffix = str(start_year) + ' to ' + str(end_year)

# A formatter to display comma-separated numbers on the y axis.
def comma_func(y, pos):
	s = '{:0,d}'.format(int(y))
	return s

comma_format = ticker.FuncFormatter(comma_func)

# A formatter to display percents on the y axis.
def percent_func(y, pos):
	s = str(y) + '%'
	return s

percent_format = ticker.FuncFormatter(percent_func)

# Plot the foreign resident population over time.
pyplot.ylabel('Population')
pyplot.xlabel('Year')
pyplot.title('Foreign Resident Population of Japan' + "\n" + year_suffix)
pyplot.ylim(0, 2500000)
pyplot.plot(years, foreign_residents, 'b-s')
pyplot.subplot(111).yaxis.set_major_formatter(comma_format)
with open('Population.1.svg', 'w') as file:
    pyplot.savefig(file, format='svg', bbox_inches='tight')

# Plot the percent of foreign residents over time.
pyplot.clf()
pyplot.ylabel('Percent of Total Population')
pyplot.xlabel('Year')
pyplot.title('Foreign Residents as a Percent of the Total Population of Japan' + "\n" + year_suffix)
pyplot.ylim(0, 2)
pyplot.plot(years, percent_foreign, 'g-^')
pyplot.subplot(111).yaxis.set_major_formatter(percent_format)
with open('Population.2.svg', 'w') as file:
    pyplot.savefig(file, format='svg', bbox_inches='tight')

# Plot the total population over time.
pyplot.clf()
pyplot.ylabel('Population')
pyplot.xlabel('Year')
pyplot.title('Total Population of Japan' + "\n" + year_suffix)
pyplot.ylim(0, 140000000)
pyplot.plot(years, total_population, 'r-o')
pyplot.subplot(111).yaxis.set_major_formatter(comma_format)
with open('Population.3.svg', 'w') as file:
    pyplot.savefig(file, format='svg', bbox_inches='tight')
